@@ -1,9 +1,4 @@
 $(document).ready(function() { 
-    // Extend the default setting to always sort on the last (date) column 
-    $.tablesorter.defaults.sortList = [[3,1]]; 
-    // Call the tablesorter plugin 
-    $("#submissions").tablesorter(); 
-
     // Set up the "select all" switch on submission page. Default to all
     // selected, handle toggling all selected/unselected. Update link text
     // to appropriate statement each time. We do this here so the page
